@@ -12,7 +12,7 @@ use Carp;
 
 use vars qw($VERSION @ISA);
 
-$VERSION = '2.09';
+$VERSION = '2.11';
 
 use HTML::Parser;
 @ISA = qw(HTML::Parser);
@@ -186,6 +186,19 @@ sub text {
   @res;
 }
 
+sub parse {
+  my $self = shift;
+  $self->_reset_state unless $self->{_parsing};
+  $self->{_parsing} ||= 1;
+  $self->SUPER::parse(@_);
+}
+
+sub eof {
+  my $self = shift;
+  $self->{_parsing} = 0;
+  $self->SUPER::eof(@_);
+}
+
 ### End HTML::Parser overrides
 
 ### Report Methods
@@ -349,11 +362,11 @@ sub _exit_table {
   # Last ditch fix for HTML mangle
   if ($ts->{in_cell}) {
     $self->_emsg("Mangled HTML in table ($self->{depth},$self->{count}), forcing exit of cell ($ts->{rc},$ts->{cc}) due to table exit\n") if $self->{debug};
-    $self->_exit_cell;
+    $ts->_exit_cell;
   }
   if ($ts->{in_row}) {
     $self->_emsg("Mangled HTML in table ($self->{depth},$self->{count}), forcing exit of row $ts->{rc} due to table exit\n") if $self->{debug};
-    $self->_exit_row;
+    $ts->_exit_row;
   }
 
   # transform from tree to grid using our rasterized template
@@ -413,6 +426,7 @@ sub _reset_state {
   $self->{_ts_sequential} = [];
   $self->{_counts}        = [];
   $self->{_in_a_table}    = 0;
+  $self->{_parsing}       = 0;
 }
 
 sub _emsg {
